@@ -1,30 +1,24 @@
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *
-* Copyright 2013 - 2022, nymea GmbH
-* Contact: contact@nymea.io
+* Copyright (C) 2013 - 2024, nymea GmbH
+* Copyright (C) 2024 - 2025, chargebyte austria GmbH
 *
-* This file is part of nymea.
-* This project including source code and documentation is protected by
-* copyright law, and remains the property of nymea GmbH. All rights, including
-* reproduction, publication, editing and translation, are reserved. The use of
-* this project is subject to the terms of a license agreement to be concluded
-* with nymea GmbH in accordance with the terms of use of nymea GmbH, available
-* under https://nymea.io/license
+* This file is part of nymea-energy-plugin-nymea.
 *
-* GNU General Public License Usage
-* Alternatively, this project may be redistributed and/or modified under the
-* terms of the GNU General Public License as published by the Free Software
-* Foundation, GNU version 3. This project is distributed in the hope that it
-* will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
-* of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
-* Public License for more details.
+* nymea-energy-plugin-nymea.s free software: you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation, either version 3 of the License, or
+* (at your option) any later version.
 *
-* You should have received a copy of the GNU General Public License along with
-* this project. If not, see <https://www.gnu.org/licenses/>.
+* nymea-energy-plugin-nymea.s distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+* GNU General Public License for more details.
 *
-* For any further details and any questions please contact us under
-* contact@nymea.io or see our FAQ/Licensing Information on
-* https://nymea.io/license/faq
+* You should have received a copy of the GNU General Public License
+* along with nymea-energy-plugin-nymea. If not, see <https://www.gnu.org/licenses/>.
 *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
@@ -439,14 +433,14 @@ void TestCharging::testEcoMode_data()
     QTest::addColumn<bool>("chargerConnected");
     QTest::addColumn<bool>("chargerPower");
     QTest::addColumn<QString>("chargerPhases");
-    QTest::addColumn<int>("chargerMaxChargingCurrent");
+    QTest::addColumn<double>("chargerMaxChargingCurrent");
     QTest::addColumn<int>("chargerMaxChargingCurrentMaxValue");
 
     // Current meter power states
     QTest::addColumn<QVariantMap>("meterPhasesPower");
 
     // Desired result on the evCharger
-    QTest::addColumn<int>("expectedChargerMaxChargingCurrent");
+    QTest::addColumn<double>("expectedChargerMaxChargingCurrent");
     QTest::addColumn<bool>("expectedChargerPower");
 
     QTest::newRow("Default: 1 phase, p: 4kW, 16A, ON")
@@ -464,14 +458,14 @@ void TestCharging::testEcoMode_data()
         << true // chargerConnected
         << false // chargerPower
         << "A" // chargerPhases
-        << 6 // chargerMaxChargingCurrent
+        << 6.0 // chargerMaxChargingCurrent
         << 16 //chargerMaxChargingCurrentMaxValue
 
         << QVariantMap({ {"A", 0000}, // W
                         {"B", 2000}, // W
                         {"C", -6000} }) // W
 
-        << 16 // expectedChargerMaxChargingCurrent
+        << 16.0 // expectedChargerMaxChargingCurrent
         << true; // expectedChargerPower
 
 
@@ -490,14 +484,14 @@ void TestCharging::testEcoMode_data()
         << true // chargerConnected
         << false // chargerPower
         << "A" // chargerPhases
-        << 6 // chargerMaxChargingCurrent
+        << 6.0 // chargerMaxChargingCurrent
         << 16 //chargerMaxChargingCurrentMaxValue
 
         << QVariantMap({ {"A", 2000}, // W
                         {"B", -2000}, // W
                         {"C", -2000} }) // W
 
-        << 7 // expectedChargerMaxChargingCurrent
+        << 7.3 // expectedChargerMaxChargingCurrent
         << true; // expectedChargerPower
 
 
@@ -516,14 +510,14 @@ void TestCharging::testEcoMode_data()
         << true // chargerConnected
         << false // chargerPower
         << "A" // chargerPhases
-        << 6 // chargerMaxChargingCurrent
+        << 6.0 // chargerMaxChargingCurrent
         << 32 //chargerMaxChargingCurrentMaxValue
 
         << QVariantMap({ {"A", -3000}, // W
                         {"B", 3000}, // W
                         {"C", -3000} }) // W
 
-        << 13 // expectedChargerMaxChargingCurrent
+        << 13.0 // expectedChargerMaxChargingCurrent
         << true; // expectedChargerPower
 
     QTest::newRow("Default: 2 phase, p: -8kW, 17A, ON")
@@ -541,14 +535,14 @@ void TestCharging::testEcoMode_data()
         << true // chargerConnected
         << false // chargerPower
         << "AB" // chargerPhases
-        << 6 // chargerMaxChargingCurrent
+        << 6.0 // chargerMaxChargingCurrent
         << 32 //chargerMaxChargingCurrentMaxValue
 
         << QVariantMap({ {"A", -4000}, // W
                         {"B", -5000}, // W
                         {"C", 1000} }) // W
 
-        << 17 // expectedChargerMaxChargingCurrent
+        << 17.4 // expectedChargerMaxChargingCurrent
         << true; // expectedChargerPower
 
     QTest::newRow("Default: 3 phase, p: -3kW, 6A, ON")
@@ -566,14 +560,14 @@ void TestCharging::testEcoMode_data()
         << true // chargerConnected
         << false // chargerPower
         << "ABC" // chargerPhases
-        << 6 // chargerMaxChargingCurrent
+        << 6.0 // chargerMaxChargingCurrent
         << 32 //chargerMaxChargingCurrentMaxValue
 
         << QVariantMap({ {"A", -1000}, // W
                         {"B", -1000}, // W
                         {"C", -1000} }) // W
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true; // expectedChargerPower
 }
 
@@ -593,12 +587,12 @@ void TestCharging::testEcoMode()
     QFETCH(bool, chargerConnected);
     QFETCH(bool, chargerPower);
     QFETCH(QString, chargerPhases);
-    QFETCH(int, chargerMaxChargingCurrent);
+    QFETCH(double, chargerMaxChargingCurrent);
     QFETCH(int, chargerMaxChargingCurrentMaxValue);
 
     QFETCH(QVariantMap, meterPhasesPower);
 
-    QFETCH(int, expectedChargerMaxChargingCurrent);
+    QFETCH(double, expectedChargerMaxChargingCurrent);
     QFETCH(bool, expectedChargerPower);
 
     QVariantMap params;
@@ -739,7 +733,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
     QTest::addColumn<bool>("chargerConnected");
     QTest::addColumn<bool>("chargerPower");
     QTest::addColumn<QString>("chargerPhases");
-    QTest::addColumn<int>("chargerMaxChargingCurrent");
+    QTest::addColumn<double>("chargerMaxChargingCurrent");
     QTest::addColumn<int>("chargerMaxChargingCurrentMaxValue");
     QTest::addColumn<int>("chargerDesiredPhaseCount");
 
@@ -747,7 +741,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
     QTest::addColumn<QVariantMap>("meterPhasesPower");
 
     // Desired result on the evCharger
-    QTest::addColumn<int>("expectedChargerMaxChargingCurrent");
+    QTest::addColumn<double>("expectedChargerMaxChargingCurrent");
     QTest::addColumn<bool>("expectedChargerPower");
     QTest::addColumn<int>("expectedChargerDesiredPhaseCount");
 
@@ -767,7 +761,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << true   // chargerPower
         << "ABC"  // chargerPhases
-        << 10     // chargerMaxChargingCurrent
+        << 10.0   // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 1      // chargerDesiredPhaseCount
 
@@ -776,7 +770,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", -1900},
                         {"C", -2000} })
 
-        << 16 // expectedChargerMaxChargingCurrent
+        << 16.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 1; // expectedChargerDesiredPhaseCount
 
@@ -795,8 +789,8 @@ void TestCharging::testEcoModePhaseSwitching_data()
 
         << true   // chargerConnected
         << false  // chargerPower
-        << "ABC"    // chargerPhases
-        << 6      // chargerMaxChargingCurrent
+        << "ABC"  // chargerPhases
+        << 6.0    // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 1      // chargerDesiredPhaseCount
 
@@ -805,7 +799,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 2000},
                         {"C", -5800} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 3; // expectedChargerDesiredPhaseCount
 
@@ -825,7 +819,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << false  // chargerPower
         << "ABC"  // chargerPhases
-        << 6      // chargerMaxChargingCurrent
+        << 6.0    // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 1      // chargerDesiredPhaseCount
 
@@ -834,7 +828,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 2000},
                         {"C", -6000} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 3; // expectedChargerDesiredPhaseCount
 
@@ -853,7 +847,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << false  // chargerPower
         << "ABC"  // chargerPhases
-        << 10     // chargerMaxChargingCurrent
+        << 10.0   // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 3      // chargerDesiredPhaseCount
 
@@ -862,7 +856,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 900},
                         {"C", -1700} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 1; // expectedChargerDesiredPhaseCount
 
@@ -881,7 +875,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << false  // chargerPower
         << "ABC"  // chargerPhases
-        << 6      // chargerMaxChargingCurrent
+        << 6.0    // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 3      // chargerDesiredPhaseCount
 
@@ -890,7 +884,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 2000},
                         {"C", -2000} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.1 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 1; // expectedChargerDesiredPhaseCount
 
@@ -909,7 +903,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << false  // chargerPower
         << "ABC"  // chargerPhases
-        << 6      // chargerMaxChargingCurrent
+        << 6.0    // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 3      // chargerDesiredPhaseCount
 
@@ -918,7 +912,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 2000},
                         {"C", -2000} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 1; // expectedChargerDesiredPhaseCount
 
@@ -937,7 +931,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
         << true   // chargerConnected
         << false  // chargerPower
         << "ABC"  // chargerPhases
-        << 6      // chargerMaxChargingCurrent
+        << 6.0    // chargerMaxChargingCurrent
         << 16     // chargerMaxChargingCurrentMaxValue
         << 3      // chargerDesiredPhaseCount
 
@@ -946,7 +940,7 @@ void TestCharging::testEcoModePhaseSwitching_data()
                         {"B", 2000},
                         {"C", -2000} })
 
-        << 6 // expectedChargerMaxChargingCurrent
+        << 6.0 // expectedChargerMaxChargingCurrent
         << true // expectedChargerPower
         << 3; // expectedChargerDesiredPhaseCount
 }
@@ -967,13 +961,13 @@ void TestCharging::testEcoModePhaseSwitching()
     QFETCH(bool, chargerConnected);
     QFETCH(bool, chargerPower);
     QFETCH(QString, chargerPhases);
-    QFETCH(int, chargerMaxChargingCurrent);
+    QFETCH(double, chargerMaxChargingCurrent);
     QFETCH(int, chargerMaxChargingCurrentMaxValue);
     QFETCH(int, chargerDesiredPhaseCount);
 
     QFETCH(QVariantMap, meterPhasesPower);
 
-    QFETCH(int, expectedChargerMaxChargingCurrent);
+    QFETCH(double, expectedChargerMaxChargingCurrent);
     QFETCH(bool, expectedChargerPower);
     QFETCH(int, expectedChargerDesiredPhaseCount);
 
